<?php

/**
 * @file
 * Contains \Drupal\link_context\Element\LinkContext.
 */

namespace Drupal\link_context\Element;

use Drupal\Core\Render\Element\Link;

/**
 * Provides a link_context render element.
 * Almost the same as link.
 * But with prefix and suffix.
 *
 * @RenderElement("link_context")
 */
class LinkContext extends Link {
  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    return array(
      '#pre_render' => array(
        array($class, 'preRenderLink'),
      ),
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function preRenderLink($element) {
    $prefix = $suffix = NULL;
    if (array_key_exists('prefix', $element['#options']['attributes'])
      && strlen($element['#options']['attributes']['prefix']) > 0) {
      $prefix = $element['#options']['attributes']['prefix'];
      unset($element['attributes']['prefix']);
    }
    if (array_key_exists('suffix', $element['#options']['attributes'])
      && strlen($element['#options']['attributes']['suffix']) > 0) {
      $suffix = $element['#options']['attributes']['suffix'];
      unset($element['attributes']['suffix']);
    }
    $element = parent::preRenderLink($element);

    if (!empty($element['#markup'])) {
      if (!is_null($prefix)) {
        $element['#markup'] = $prefix . $element['#markup'];
      }
      if (!is_null($suffix)) {
        $element['#markup'] = $element['#markup'] . $suffix;
      }
    }
    return $element;
  }
}